from .utils import add_to_recently_visited


class RecentlyVisitedPageMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        # Process the request
        response = self.get_response(request)

        # Add the current URL to recently visited pages for the logged-in user
        if response.status_code == 200 and request.user.is_authenticated:
            current_url = request.build_absolute_uri()
            user_id = request.user.id
            add_to_recently_visited(user_id, current_url)

        return response
    



from setuptools import setup, find_packages

setup(
    name='recently_visited_page_middleware',
    version='0.1.2',
    author='Abiola Adeshina',
    author_email='abiolaadeshinaadedayo@gmail.com',
    description='Django middleware for tracking recently visited pages',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/Abiorh001/recently_visited_page_middleware.git',
    packages=find_packages(),
    install_requires=[
        'Django',
        'djangorestframework',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
